@@ -21,7 +21,7 @@ require AutoLoader;
 @EXPORT = qw(
 	
 );
-$VERSION = '2.03';
+$VERSION = '2.04';
 
 my %EuroRates = (
          BEF => {EUR=>0.0247899055505,   BEF => 1},
@@ -202,8 +202,7 @@ __END__
 
 =head1 NAME
 
-Finance::Currency::Convert -
-Convert currencies and fetch their exchange rates (with Finance::Quote)
+Finance::Currency::Convert - Convert currencies and fetch their exchange rates (with Finance::Quote)
 
 =head1 SYNOPSIS
 
